package com.caimei365.commodity.controller;

import com.caimei365.commodity.model.ResponseJson;
import com.caimei365.commodity.model.po.ProductParameterPo;
import com.caimei365.commodity.model.vo.ProductRepairVo;
import com.caimei365.commodity.model.search.ProductListVo;
import com.caimei365.commodity.model.vo.*;
import com.caimei365.commodity.service.PageService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/4/12
 */
@Api(tags="商品页面数据API")
@RestController
@RequiredArgsConstructor
@RequestMapping("/commodity")
public class ProductPageApi {

    private final PageService pageService;
    /**
     * 获取分类列表
     *
     * @param typeSort 分类类型：1产品，2仪器
     * @param source   请求来源：www,crm
     */
    @ApiOperation("获取分类菜单（旧：/product/classify）")
    @ApiImplicitParams({
        @ApiImplicitParam(required = true, name = "typeSort", value = "分类类型：1产品，2仪器，0全部"),
        @ApiImplicitParam(required = false, name = "source", value = "请求来源：www,crm")
    })
    @GetMapping("/classify")
    public ResponseJson<List<BigTypeVo>> getClassify(Integer typeSort, String source) {
        return pageService.getClassify(typeSort, source);
    }

    /**
     * 产品/仪器页面数据
     *
     * @param pageId 页面信息id
     * @param userId 用户id
     * @param source 来源：1网站，2小程序
     */
    @ApiOperation("产品/仪器页面数据（旧：/home/instrumentData）")
    @ApiImplicitParams({
        @ApiImplicitParam(required = true, name = "pageId", value = "页面信息id"),
        @ApiImplicitParam(required = false, name = "userId", value = "用户id"),
        @ApiImplicitParam(required = false, name = "source", value = "来源：1网站，2小程序")
    })
    @GetMapping("/classify/product")
    public ResponseJson<Map<String, Object>> getClassifyData(Integer pageId, Integer userId, Integer source) {
        if (pageId == null) {
            return ResponseJson.error("参数异常", null);
        }
        return pageService.getClassifyData(pageId, userId, source);
    }

    /**
     * 首页楼层数据
     *
     * @param userId 用户id
     * @param source 来源 : 1 网站 ; 2 小程序
     */
    @ApiOperation("首页楼层数据(旧：/home/data)")
    @ApiImplicitParams({
        @ApiImplicitParam(required = false, name = "userId", value = "用户id"),
        @ApiImplicitParam(required = false, name = "source", value = "来源：1网站，2小程序")
    })
    @GetMapping("/home/floor")
    public ResponseJson<Map<String, Object>> getHomeData(Integer userId, Integer source) {
        return pageService.getHomeData(userId, source);
    }

    /**
     * 首页基础数据（小程序）
     *
     * @param source 来源 : 1 网站 ; 2 小程序
     */
    @ApiOperation("首页楼层数据(旧：/home/init)")
    @ApiImplicitParam(required = false, name = "source", value = "来源：1网站，2小程序")
    @GetMapping("/home/init")
    public ResponseJson<Map<String, Object>> getHomeInit(Integer source) {
        return pageService.getHomeInit(source);
    }


    /**
     * 活动专题楼层数据（美博会）
     *
     * @param pageId 页面id
     * @param userId 用户id
     * @param source 来源 : 1 网站 ; 2 小程序
     */
    @ApiOperation("活动专题楼层数据（美博会）(旧：/home/activity/data)")
    @ApiImplicitParams({
        @ApiImplicitParam(required = false, name = "pageId", value = "页面id"),
        @ApiImplicitParam(required = false, name = "userId", value = "用户id"),
        @ApiImplicitParam(required = false, name = "source", value = "来源：1网站，2小程序")
    })
    @GetMapping("/page/floor")
    public ResponseJson<Map<String, Object>> getPageData(Integer pageId, Integer userId, Integer source) {
        return pageService.getPageData(pageId, userId, source);
    }

    /**
     * 楼层详情
     *
     * @param floorId 楼层id
     * @param userId 用户id
     * @param source 来源 : 1 网站 ; 2 小程序
     */
    @ApiOperation("楼层详情(旧：/home/floorContentDetails)")
    @ApiImplicitParams({
        @ApiImplicitParam(required = false, name = "floorId", value = "楼层id"),
        @ApiImplicitParam(required = false, name = "userId", value = "用户id"),
        @ApiImplicitParam(required = false, name = "source", value = "来源：1网站，2小程序")
    })
    @GetMapping("/page/floor/details")
    public ResponseJson<Map<String, Object>> getPageFloorData(Integer floorId, Integer userId, Integer source) {
        return pageService.getPageFloorData(floorId, userId, source);
    }

    /**
     * 分页详情楼层详情
     *
     * @param centreId 分页详情楼层id
     * @param userId 用户id
     * @param source 来源 : 1 网站 ; 2 小程序
     */
    @ApiOperation("分页详情楼层详情(旧：/home/pageFloorDetails)")
    @ApiImplicitParams({
        @ApiImplicitParam(required = false, name = "centreId", value = "分页详情楼层id"),
        @ApiImplicitParam(required = false, name = "userId", value = "用户id"),
        @ApiImplicitParam(required = false, name = "source", value = "来源：1网站，2小程序")
    })
    @GetMapping("/page/floor/centre")
    public ResponseJson<Map<String, Object>> getPageCentreData(Integer centreId, Integer userId, Integer source) {
        return pageService.getPageCentreData(centreId, userId, source);
    }

    /**
     * 商品详情页
     *
     * @param productId 商品Id
     * @param userId    用户Id
     */
    @ApiOperation("商品详情页(旧：/product/details)")
    @ApiImplicitParams({
        @ApiImplicitParam(required = false, name = "userId", value = "用户id"),
        @ApiImplicitParam(required = false, name = "productId", value = "商品Id")
    })
    @GetMapping("/product/details")
    public ResponseJson<ProductDetailVo> getProductDetails(Integer productId, Integer userId) {
        return pageService.getProductDetails(productId, userId);
    }

    /**
     * 再次购买商品列表
     *
     * @param userId 用户Id
     */
    @ApiOperation("再次购买商品列表（旧：/repeat/buyAgain）")
    @ApiImplicitParams({
        @ApiImplicitParam(required = false, name = "userId", value = "用户Id"),
        @ApiImplicitParam(required = false, name = "pageNum", value = "页码"),
        @ApiImplicitParam(required = false, name = "pageSize", value = "每页数量")
    })
    @GetMapping("/product/repeat")
    public ResponseJson<PaginationVo<ProductItemVo>> getBuyAgainProducts(Integer userId,
                                                                         @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                                         @RequestParam(value = "pageSize", defaultValue = "10") int pageSize) {
        return pageService.getBuyAgainProducts(userId, pageNum, pageSize);
    }


    /**
     * 项目仪器详情页
     */
    @ApiOperation("项目仪器详情页（旧：/equipment/recommend）")
    @ApiImplicitParam(required = false, name = "equipmentId", value = "项目仪器Id")
    @GetMapping("/equipment/details")
    @ResponseBody
    public ResponseJson<EquipmentVo> getEquipmentDetails(Integer equipmentId) {
        return pageService.getEquipmentDetails(equipmentId);
    }


    /**
     * 商品详情页-图片
     *
     * @param productId 商品Id
     */
    @ApiOperation("商品详情-图片(旧：/product/detail/images)")
    @ApiImplicitParam(required = false, name = "productId", value = "商品Id")
    @GetMapping("/product/detail/images")
    public ResponseJson<List<String>> getProductDetailImages(Integer productId) {
        return pageService.getProductDetailImages(productId);
    }

    /**
     * 商品详情页-相关参数
     *
     * @param productId 商品Id
     */
    @ApiOperation("商品详情-相关参数(旧：/product/detail/parameter)")
    @ApiImplicitParam(required = false, name = "productId", value = "商品Id")
    @GetMapping("/detail/params")
    public ResponseJson<List<ProductParameterPo>> getProductParameters(Integer productId) {
        return pageService.getProductParameters(productId);
    }

    /**
     * 商品详情页-相关推荐
     *
     * @param productId 商品Id
     * @param recommendType 相关推荐类型: 0自动选择, 1手动推荐
     * @param userId    用户Id
     */
    @ApiOperation("商品详情-相关推荐(旧：/product/detail/recommend)")
    @ApiImplicitParams({
        @ApiImplicitParam(required = false, name = "productId", value = "商品Id"),
        @ApiImplicitParam(required = false, name = "recommendType", value = "相关推荐类型: 0自动选择, 1手动推荐"),
        @ApiImplicitParam(required = false, name = "userId", value = "用户id")
    })
    @GetMapping("/detail/recommend")
    public ResponseJson<List<ProductListVo>> getProductDetailRecommends(Integer productId, Integer recommendType, Integer userId) {
        return pageService.getProductDetailRecommends(productId, recommendType, userId);
    }

    /**
     * 商品维修（链接分享数据）
     * @param code 维修code
     */
    @ApiOperation("商品维修（链接分享）")
    @ApiImplicitParam(required = true, name = "code", value = "维修code")
    @GetMapping("/product/repair")
    public ResponseJson<ProductRepairVo> getProductRepair(String code) {
        return pageService.getProductRepair(code);
    }


    /**
     * 商品资料列表
     */
    @ApiOperation("商品资料列表")
    @ApiImplicitParams({
            @ApiImplicitParam(required = false, name = "keyword", value = "搜索关键词"),
            @ApiImplicitParam(required = false, name = "productType", value = "商品属性：1产品，2仪器"),
            @ApiImplicitParam(required = false, name = "pageNum", value = "页码"),
            @ApiImplicitParam(required = false, name = "pageSize", value = "每页数量")
    })
    @GetMapping("/product/archive")
    public ResponseJson<PaginationVo<ArchiveVo>> getProductArchive(String keyword, Integer productType, Integer pageNum, Integer pageSize) {
        return pageService.getProductArchive(keyword, productType, pageNum, pageSize);
    }

    /**
     * 商品资料详情
     */
    @GetMapping("/product/archive/detail")
    public ResponseJson<ArchiveDetailVo> getArchiveDetail(Integer archiveId, Integer userId) {
        if (null == archiveId || null == userId) {
            return ResponseJson.error("参数错误",  null);
        }
        return pageService.getArchiveDetail(archiveId, userId);
    }
}
