package com.caimei365.commodity.controller;

import com.caimei365.commodity.model.ResponseJson;
import com.caimei365.commodity.model.vo.LadderPriceVo;
import com.caimei365.commodity.model.vo.PriceVo;
import com.caimei365.commodity.service.PriceService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.apache.commons.lang.StringUtils;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * 商品价格API
 *
 * @author : Charles
 * @date : 2021/4/9
 */
@Api(tags = "商品价格API")
@RestController
@RequiredArgsConstructor
@RequestMapping("/commodity/price")
public class ProductPriceApi {

    private final PriceService priceService;

    /**
     * 获取商品详情价格
     *
     * @param userId    用户Id
     * @param productId 商品Id
     */
    @ApiOperation("获取商品详情价格（旧：/product/detail/price）(注意：supplierId更改为shopId)")
    @ApiImplicitParams({
            @ApiImplicitParam(required = true, name = "userId", value = "用户Id"),
            @ApiImplicitParam(required = true, name = "productId", value = "商品Id")
    })
    @GetMapping("detail")
    public ResponseJson<PriceVo> getDetailPrice(Integer userId, Integer productId) {
        if (null == userId || null == productId) {
            return ResponseJson.error("参数错误", null);
        }
        return priceService.getDetailPrice(userId, productId);
    }

    /**
     * 获取商品列表价格
     *
     * @param userId     用户Id
     * @param productIds 商品Id
     */
    @ApiOperation("获取商品列表价格（旧：/product/listPrice）(注意：supplierId更改为shopId)")
    @ApiImplicitParams({
            @ApiImplicitParam(required = true, name = "userId", value = "用户Id"),
            @ApiImplicitParam(required = true, name = "productIds", value = "商品Ids,逗号拼接"),
            @ApiImplicitParam(required = true, name = "source", value = "来源 : 1 网站 ; 2 小程序")
    })
    @GetMapping("/list")
    public ResponseJson<List<PriceVo>> getProductPrice(Integer userId, String productIds, Integer source) {
        if (null == userId || StringUtils.isEmpty(productIds) || source == null) {
            return ResponseJson.error("参数错误", null);
        }
        return priceService.getListPrice(userId, productIds, source);
    }

    /**
     * 获取阶梯价格
     *
     * @param productId 商品Id
     */
    @ApiOperation("获取阶梯价格（旧：/product/ladderPrice）(注意：supplierId更改为shopId)")
    @ApiImplicitParam(required = true, name = "productId", value = "商品Id")
    @GetMapping("/ladder")
    public ResponseJson<List<LadderPriceVo>> getLadderPrice(Integer productId) {
        if (null == productId) {
            return ResponseJson.error("参数错误", null);
        }
        return priceService.getLadderPrice(productId);
    }

}
