package com.caimei365.commodity.controller;

import com.caimei365.commodity.model.ResponseJson;
import com.caimei365.commodity.model.vo.CombinationVo;
import com.caimei365.commodity.model.vo.PaginationVo;
import com.caimei365.commodity.model.vo.ProductItemVo;
import com.caimei365.commodity.service.SellerService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/4/23
 */
@Api(tags="协销商品API")
@RestController
@RequiredArgsConstructor
@RequestMapping("/commodity/seller")
public class ProductSellerApi {
    private final SellerService sellerService;

    /**
     * 协销搜索商品(单一)
     */
    @ApiOperation("协销搜索单一商品（旧：/seller/product/search）")
    @ApiImplicitParams({
        @ApiImplicitParam(required = false, name = "searchWord", value = "搜索关键字"),
        @ApiImplicitParam(required = false, name = "clubUserId", value = "机构用户Id"),
        @ApiImplicitParam(required = false, name = "pageNum", value = "页码"),
        @ApiImplicitParam(required = false, name = "pageSize", value = "每页数量")
    })
    @GetMapping("/product/single")
    public ResponseJson<PaginationVo<ProductItemVo>> searchSingleProducts(String searchWord, Integer clubUserId,
                                                                            @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                                            @RequestParam(value = "pageSize", defaultValue = "10") int pageSize) {
        return sellerService.searchSingleProducts(searchWord, clubUserId, pageNum, pageSize);
    }

    /**
     * 协销搜索商品(组合)
     */
    @ApiOperation("协销搜索组合商品（旧：/seller/combinationProduct/search）")
    @ApiImplicitParams({
        @ApiImplicitParam(required = false, name = "searchWord", value = "搜索关键字"),
        @ApiImplicitParam(required = false, name = "clubUserId", value = "机构用户Id"),
        @ApiImplicitParam(required = false, name = "pageNum", value = "页码"),
        @ApiImplicitParam(required = false, name = "pageSize", value = "每页数量")
    })
    @GetMapping("/product/combination")
    public ResponseJson<PaginationVo<CombinationVo>> searchCombinationProducts(String searchWord, Integer clubUserId,
                                                                               @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                                               @RequestParam(value = "pageSize", defaultValue = "5") int pageSize) {
        return sellerService.searchCombinationProducts(searchWord, clubUserId, pageNum, pageSize);
    }

}
