package com.caimei365.commodity.controller;

import com.caimei365.commodity.model.ResponseJson;
import com.caimei365.commodity.model.dto.BrandDto;
import com.caimei365.commodity.model.dto.FeaturedDto;
import com.caimei365.commodity.model.dto.ProductDto;
import com.caimei365.commodity.model.dto.SoldOutDto;
import com.caimei365.commodity.model.po.BrandPo;
import com.caimei365.commodity.model.search.ProductListVo;
import com.caimei365.commodity.model.vo.BrandVo;
import com.caimei365.commodity.model.vo.PaginationVo;
import com.caimei365.commodity.model.vo.ProductFormVo;
import com.caimei365.commodity.service.ShopService;
import io.swagger.annotations.*;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/4/16
 */
@Api(tags="供应商商品API")
@RestController
@RequiredArgsConstructor
@RequestMapping("/commodity/shop")
public class ProductShopApi {
    private final ShopService shopService;

    /**
     * 供应商-主推商品
     */
    @ApiOperation("供应商-主推商品（旧：/supplier/home/products）")
    @ApiImplicitParams({
        @ApiImplicitParam(required = true, name = "shopId", value = "供应商Id（旧：supplierId）"),
        @ApiImplicitParam(required = false, name = "identity", value = "用户身份：1协销，2会员机构，3供应商，4普通机构")
    })
    @GetMapping("/product/main")
    public ResponseJson<List<ProductListVo>> getSupplierMainProducts(Integer shopId, @RequestParam(value = "identity", defaultValue = "0") Integer identity) {
        return shopService.getMainProducts(shopId, identity);
    }

    /**
     * 供应商-我的商品列表
     */
    @ApiOperation("供应商-我的商品（旧：/supplier/myProduct）")
    @ApiImplicitParams({
        @ApiImplicitParam(required = true, name = "shopId", value = "供应商Id"),
        @ApiImplicitParam(required = false, name = "name", value = "商品名称"),
        @ApiImplicitParam(required = false, name = "productCode", value = "货号"),
        @ApiImplicitParam(required = false, name = "validFlag", value = "状态：0逻辑删除，1待审核，2已上架，3已下架，8审核未通过，9已隐身，10已冻结"),
        @ApiImplicitParam(required = false, name = "featuredFlag", value = "是否主推：0否，1是"),
        @ApiImplicitParam(required = false, name = "commodityType", value = "商品属性：1产品，2仪器"),
        @ApiImplicitParam(required = false, name = "bigTypeId", value = "一级分类Id"),
        @ApiImplicitParam(required = false, name = "smallTypeId", value = "二级分类Id"),
        @ApiImplicitParam(required = false, name = "tinyTypeId", value = "三级级分类Id"),
        @ApiImplicitParam(required = false, name = "pageNum", value = "页码"),
        @ApiImplicitParam(required = false, name = "pageSize", value = "每页数量")
    })
    @GetMapping("/product/list")
    public ResponseJson<Map<String, Object>> getShopProducts(Integer shopId, String name, String productCode,
                                                             Integer validFlag, Integer featuredFlag, Integer commodityType, Integer bigTypeId, Integer smallTypeId, Integer tinyTypeId,
                                                             @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                             @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        return shopService.getShopProducts(shopId, name, productCode, validFlag, featuredFlag, commodityType, bigTypeId, smallTypeId, tinyTypeId, pageNum, pageSize);
    }

    /**
     * 供应商-发布商品
     *
     * @param productDto {
     *                   aliasName	    内部商品名称
     *                   allAreaFlag	销售区域：1全部区域， 0指定区域
     *                   bigTypeId	    一级分类id
     *                   brandId	    品牌id
     *                   brandName	    品牌名称
     *                   commodityType	商品属性：1产品，2仪器
     *                   costPrice	    成本价
     *                   detailInfo	    商品详情信息
     *                   includedTax	是否含税：0不含税，1含税，2未知
     *                   invoiceType	发票类型
     *                   machineType	械字号类型
     *                   minBuyNumber	最小购买量
     *                   name	        商品名称
     *                   normalPrice	市场价
     *                   orderInfo	    订购方案
     *                   price	        机构价格
     *                   productCode	商品货号
     *                   productType	商品类型：0其它，1妆字号，2械字号
     *                   provinceIds	指定的销售区域
     *                   qualificationImg 械字号资质证书图
     *                   searchKey	      搜索关键词
     *                   serviceInfo	  服务详情
     *                   shopId	         供应商id
     *                   smallTypeId	 二级分类id
     *                   step	         购买数量
     *                   stock	         库存
     *                   tags	         商品标签，逗号隔开
     *                   taxPoint	     开票税点
     *                   tinyTypeId	     三级分类id
     *                   unit	         包装规格
     *                   }
     */
    @ApiOperation("供应商-发布商品（旧：/supplier/releaseProduct）")
    @PostMapping("/product/release")
    public ResponseJson releaseProduct(ProductDto productDto){
        return shopService.releaseProduct(productDto);
    }

    /**
     * 供应商-商品编辑回显
     *
     * @param productId 商品Id
     */
    @ApiOperation("供应商-商品编辑回显（旧：/supplier/productInfo）")
    @ApiImplicitParam(required = true, name = "productId", value = "商品Id")
    @GetMapping("/product/form")
    public ResponseJson<ProductFormVo> getProductForm(Integer productId) {
        return shopService.getProductForm(productId);
    }

    /**
     * 供应商-商品编辑-品牌联想
     */
    @ApiOperation("供应商-商品编辑-品牌联想（旧：/supplier/brandManagement）")
    @ApiImplicitParams({
        @ApiImplicitParam(required = true, name = "userId", value = "用户Id"),
        @ApiImplicitParam(required = true, name = "name", value = "关键词")
    })
    @GetMapping("/brand/select")
    public ResponseJson<List<BrandVo>> brandAssociation(Integer userId, String name) {
        return shopService.brandAssociation(userId, name);
    }

    /**
     * 供应商-品牌检测
     */
    @ApiOperation("供应商-品牌检测（旧：/supplier/brandDetection）")
    @ApiImplicitParam(required = true, name = "name", value = "品牌名称")
    @GetMapping("/brand/check")
    public ResponseJson<BrandVo> brandDetection(String name) {
        return shopService.brandDetection(name);
    }

    /**
     * 供应商-提交新品牌
     *
     * @param brandDto {
     *                 name        品牌名字
     *                 source      添加来源 0:后台添加，1:供应商添加
     *                 userId      添加用户ID,后台则为后台用户ID,供应商则为供应商用户ID
     *                 logo        品牌logo
     *                 description 品牌描述
     * }
     */
    @ApiOperation("供应商-提交新品牌（旧：/supplier/addBrand）")
    @PostMapping("/brand/add")
    public ResponseJson<BrandPo> addBrand(BrandDto brandDto) {
        return shopService.addBrand(brandDto);
    }

    /**
     * 供应商-品牌管理
     */
    @ApiOperation("供应商-品牌管理（旧：/supplier/brandManagement）")
    @ApiImplicitParams({
        @ApiImplicitParam(required = false, name = "name", value = "品牌名称"),
        @ApiImplicitParam(required = false, name = "status", value = "品牌状态 0:待审核，1:审核通过，2:审核失败"),
        @ApiImplicitParam(required = false, name = "userId", value = "用户Id"),
        @ApiImplicitParam(required = false, name = "pageNum", value = "页码"),
        @ApiImplicitParam(required = false, name = "pageSize", value = "每页数量")
    })
    @GetMapping("/brand/list")
    public ResponseJson<PaginationVo<BrandVo>> brandManagement(String name, Integer status, Integer userId,
                                                               @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                               @RequestParam(value = "pageSize", defaultValue = "10") int pageSize) {
        return shopService.brandManagement(name, status, userId, pageNum, pageSize);
    }

    /**
     * 供应商-添加,删除主页推荐
     *
     * @param featuredDto {
     *                    productId    商品Id
     *                    featuredFlag 供应商主推商品标志 0删除 1添加
     *                    shop         供应商Id
     *                    }
     */
    @ApiOperation("供应商-添加,删除主页推荐（旧：/supplier/switchFeatured）")
    @PostMapping("/featured/switch")
    public ResponseJson switchFeatured(FeaturedDto featuredDto) {
        return shopService.switchFeatured(featuredDto);
    }

    /**
     * 供应商-批量下架商品
     *
     * @param soldOutDto {productIds 商品id集合,以','隔开}
     */
    @ApiOperation("供应商-批量下架商品（旧：/supplier/soldOut）")
    @PostMapping("/product/offline")
    public ResponseJson soldOut(SoldOutDto soldOutDto) {
        return shopService.soldOutProducts(soldOutDto.getProductIds());
    }

}
