package com.caimei365.commodity.controller;

import com.caimei365.commodity.model.ResponseJson;
import com.caimei365.commodity.model.vo.BigTypeVo;
import com.caimei365.commodity.model.vo.SmallTypeVo;
import com.caimei365.commodity.model.vo.TinyTypeVo;
import com.caimei365.commodity.service.ProductTypeService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/4/22
 */
@Api(tags="商品分类API")
@RestController
@RequiredArgsConstructor
@RequestMapping("/commodity/type")
public class ProductTypeApi {
    private final ProductTypeService productTypeService;

    /**
     * 根据商品属性获取一级分类下拉
     *
     * @param typeSort 分类类型，1产品，2仪器
     */
    @ApiOperation("获取一级分类下拉列表（旧：/supplier/primaryClassification）")
    @ApiImplicitParam(required = true, name = "typeSort", value = "类型，1产品，2仪器")
    @GetMapping("/first")
    public ResponseJson<List<BigTypeVo>> getBigTypeSelect(Integer typeSort) {
        return productTypeService.getBigTypeSelect(typeSort);
    }

    /**
     * 获取二级分类下拉列表
     *
     * @param bigTypeId 一级分类Id
     */
    @ApiOperation("获取二级分类下拉列表（旧：/supplier/secondaryClassification）")
    @ApiImplicitParam(required = true, name = "bigTypeId", value = "一级分类Id")
    @GetMapping("/second")
    public ResponseJson<List<SmallTypeVo>> getSmallTypeSelect(Integer bigTypeId) {
        return productTypeService.getSmallTypeSelect(bigTypeId);
    }

    /**
     * 获取三级分类下拉列表
     *
     * @param smallTypeId 二级分类Id
     */
    @ApiOperation("获取三级分类下拉列表（旧：/supplier/threeLevelClassification）")
    @ApiImplicitParam(required = true, name = "smallTypeId", value = "二级分类Id")
    @GetMapping("/third")
    public ResponseJson<List<TinyTypeVo>> getTinyTypeSelect(Integer smallTypeId) {
        return productTypeService.getTinyTypeSelect(smallTypeId);
    }

    /**
     * 根据Id获取分类（小程序）
     *
     * @param typeId  分类Id
     * @param idType  typeId类型：1:bigType，2:smallType，3:tinyType
     * @param source  请求来源：www,crm
     */
    @ApiOperation("根据Id获取分类（小程序）（旧：/product/typeId/classify）")
    @ApiImplicitParams({
        @ApiImplicitParam(required = true, name = "typeId", value = "分类Id"),
        @ApiImplicitParam(required = true, name = "idType", value = "typeId类型：1:一级分类，2:二级分类，3:三级分类"),
        @ApiImplicitParam(required = false, name = "source", value = "请求来源：www,crm")
    })
    @GetMapping("/id")
    public ResponseJson<BigTypeVo> getTypeById(Integer typeId, Integer idType, String source) {
        return productTypeService.getTypeById(typeId, idType, source);
    }

}
