package com.caimei365.commodity.mapper;

import com.caimei365.commodity.model.po.ArchiveFilePo;
import com.caimei365.commodity.model.po.ArchivePo;
import com.caimei365.commodity.model.search.ProductListVo;
import com.caimei365.commodity.model.vo.*;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/4/12
 */
@Mapper
public interface PageMapper {
    /**
     * 查询页面信息
     *
     * @param pageId 页面Id
     */
    Integer getPageTypeSort(Integer pageId);

    /**
     * 查询分页详情热搜词
     *
     * @param pageId
     */
    List<HotSearchVo> getHotSearchByPageId(Integer pageId, Integer source);

    /**
     * 首页楼层
     *
     * @param source
     */
    List<PageFloorVo> getHomePageFloor(Integer source);

    /**
     * 查询页面信息商品楼层
     *
     * @param pageId
     */
    List<PageFloorVo> getFloorByPageId(Integer pageId, Integer source);

    /**
     * 查询楼层内容
     *
     * @param id 页面id
     */
    FloorContentVo getFloorContentById(Integer id);

    /**
     * 查询楼层相关图片
     *
     * @param id     页面id
     * @param source
     */
    List<FloorImageVo> getFloorImageById(Integer id, Integer source);

    /**
     * 查询楼层内容
     *
     * @param id 楼层id
     */
    FloorContentVo getFloorContentByCentreId(Integer id);

    /**
     * 查询楼层相关图片
     *
     * @param id     楼层id
     * @param source
     */
    List<FloorImageVo> getFloorImageByCentreId(Integer id, Integer source);

    /**
     * 获取商品及价格
     *
     * @param productId
     */
    ProductItemVo getProductItemById(Integer productId);

    /**
     * 优质供应商楼层
     */
    ShopFloorVo getSupplierFloorImage();

    /**
     * 查询优质供应商数据
     *
     * @param source
     */
    List<ShopImageVo> getSupplierImage(Integer source);

    /**
     * 商品详情页
     */
    ProductDetailVo getProductDetails(Integer productId);

    /**
     * 再次购买
     *
     * @param userId 用户Id
     */
    List<ProductItemVo> getBuyAgainProducts(Integer userId);

    /**
     * 项目仪器详情页
     *
     * @param equipmentId
     */
    EquipmentVo getEquipmentById(Integer equipmentId);

    /**
     * 根据仪器id和类型id获取仪器参数
     */
    List<EquipmentParameterVo> getEquipmentParametersByType(Integer equipmentId, Integer typeId);

    /**
     * 二级专题楼层下的数据
     */
    List<ImageLinkVo> getImageLinkByFloorId(Integer floorId);

    /**
     * 详情-相关推荐
     */
    List<ProductListVo> getProductRecommendsById(Integer productId);

    List<ProductListVo> getAutoProductRecommends(Integer productId);

    /**
     * 页面数据
     */
    CmPageVo findCmPageById(Integer pageId);

    /**
     * 获取搜索热门关键字
     */
    List<String> getSearchKeyword();

    /**
     * 获取头部菜单
     */
    List<TopMenuVo> getTopMenus(Integer source);

    /**
     * 获取底部链接分类
     */
    List<BaseLinkVo> getHelpPageTypes();

    /**
     * 根据分类获取底部链接
     */
    List<BaseLinkVo> getHelpPagesByType(@Param("typeId") Integer typeId);

    /**
     * 获取友情链接
     */
    List<BaseLinkVo> getFriendLinks();

    /**
     * 仪器维修表ID
     */
    Integer getMaintenanceIdByCode(String code);

    /**
     * 维修详情
     */
    ProductRepairVo getMaintenanceById(Integer id);

    /**
     * 查询所有有效的优惠券
     *
     * @param userId
     * @return
     */
    List<CouponVo> findAllCoupon(Integer userId);

    /**
     * 查询所有优惠券指定商品id
     *
     * @param couponId 优惠券id
     * @param source   来源: 1小程序 2pc商城
     * @return
     */
    List<Integer> findAllProductId(@Param("couponId") Integer couponId, @Param("source") Integer source);

    /**
     * 查询商品资料列表
     *
     * @param keyword     搜索关键词
     * @param productType 商品属性：1产品，2仪器
     * @return
     */
    List<ArchiveVo> getProductArchiveList(@Param("keyword") String keyword, @Param("productType") Integer productType);

    /**
     * 获取图片资料列表
     * @param archiveId   商品资料id
     * @return
     */
    List<ArchiveContentVo> getImageArchiveList(Integer archiveId);

    /**
     * 获取视频资料列表
     * @param archiveId   商品资料id
     * @return
     */
    List<ArchiveContentVo> getVideoArchiveList(Integer archiveId);

    /**
     * 获取文件资料列表
     * @param archiveId   商品资料id
     * @return
     */
    List<ArchiveContentVo> getFileArchiveList(Integer archiveId);

    /**
     * 获取图片资料图片列表
     * @param archiveContentId  资料内容id
     * @return
     */
    List<String> getArchiveImageList(Integer archiveContentId);

    /**
     * 获取商品资料文件
     * @param archiveContentId  资料内容id
     * @return
     */
    ArchiveFilePo getArchiveFile(Integer archiveContentId);

    /**
     * 获取商品资料信息
     * @param archiveId 商品资料id
     * @return
     */
    ArchivePo getArchiveByArchiveId(Integer archiveId);

    /**
     * 获取机构类型
     * @param userId 用户id
     * @return
     */
    Integer getClubTypeByUserId(Integer userId);

    /**
     * 根据商品id获取资料id
     * @param productId 商品id
     * @return
     */
    Integer getArchiveIdById(Integer productId);

    /**
     * 查询商品资料抵扣采美豆记录
     * @param userId
     * @param archiveId
     * @return
     */
    Integer findBeansHistoryByArchiveId(Integer userId, Integer archiveId);
}
