package com.caimei365.commodity.mapper;

import com.caimei365.commodity.model.vo.LadderPriceVo;
import com.caimei365.commodity.model.vo.PriceVo;
import com.caimei365.commodity.model.vo.TaxVo;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/4/9
 */
@Mapper
public interface PriceMapper {
    /**
     * 根据用户Id查询用户身份
     */
    Integer getIdentityByUserId(Integer userId);
    /**
     * 根据商品id查找价格
     */
    PriceVo getDetailPrice(Integer productId);
    /**
     * 根据商品id集合查找 价格列表
     */
    List<PriceVo> getListPriceByProductIds(@Param("productIds") List<Integer> productIds);
    /**
     * 根据商品ID查询阶梯价列表
     */
    List<LadderPriceVo> getLadderPricesByProductId(Integer productId);
    /**
     * 获取最低阶梯价（价格最低，阶梯数最大）
     */
    LadderPriceVo findLowerLadderPrice(Integer productId);
    /**
     * 获取最高阶梯价（价格最高，阶梯数最小）
     */
    LadderPriceVo findMaxLadderPrice(Integer productId);
    /**
     * 根据商品ID和用户ID 查询复购价
     */
    Double getRepurchasePrice(@Param("productId") Integer productId, @Param("userId") Integer userId);
    /**
     * 根据商品ID含税和发票信息
     */
    TaxVo getTaxByProductId(Integer productId);
}
