package com.caimei365.commodity.mapper;

import com.caimei365.commodity.model.search.*;
import com.caimei365.commodity.model.search.ArticleListVo;
import com.caimei365.commodity.model.search.EquipmentListVo;
import com.caimei365.commodity.model.search.ProductListVo;
import com.caimei365.commodity.model.search.ShopListVo;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;


/**
 * Description
 *
 * @author : Charles
 * @date : 2020/5/13
 */
@Mapper
public interface SearchMapper {
    /**
     * 根据商品id查找文档数据
     * @param productId
     */
    ProductDO searchProductById(Integer productId);
    /**
     * 获取商品数量
     */
    Integer findProductCount();
    /**
     * 获取商品列表
     */
    List<ProductDO> searchProductList();
    /**
     * 根据商品id查找 星范商品数量
     */
    Integer countMallProduct(Integer productId);
    /**
     * 根据商品id查找 星范商品
     */
    MallProductDO searchMallProductByProductId(Integer productId);
    /**
     * 根据商品id查找 星范阶梯价标志
     */
    Integer getMallLadderPriceFlag(Integer productId);
    /**
     * 根据商品id查找 星范最小阶梯价
     */
    Double getMallLowerLadderPrice(Integer productId);
    /**
     * 获取供应商数量
     */
    Integer findSupplierCount();
    /**
     * 获取供应商列表
     */
    List<SupplierDO> searchSupplierList();
    /**
     * 根据供应商Id查找文档数据
     */
    SupplierDO searchSupplierById(Integer shopId);

    /**
     * 获取项目仪器数量
     */
    Integer findEquipmentCount();
    /**
     * 获取项目仪器列表
     */
    List<EquipmentDO> searchEquipmentList();
    /**
     * 根据项目仪器Id查找文档数据
     */
    EquipmentDO searchEquipmentById(Integer equipmentId);

    /**
     * 获取文章数量
     */
    Integer findArticleCount();
    /**
     * 获取文章列表
     */
    List<ArticleDO> searchArticleList();
    /**
     * 根据文章Id查找文档数据
     */
    ArticleDO searchArticleById(Integer articleId);
    /**
     * 根据文章标签查找标签Id
     */
    List<Integer> findLabelIdsByName(@Param("labelTexts") String[] labelTexts);
    /**
     * 根据文章Id查找标签文本
     */
    String findLabelNameById(@Param("labelId") Integer labelId);
    /**
     * 获取所有失效商品数量
     */
    Integer findProductInvalidCount();
    /**
     * 获取失效商品IDs
     */
    List<Integer> findProductInvalidIds();
    /**
     * 根据商品ID获取星范ID
     */
    Integer findMallIdByProductId(Integer productId);
    /**
     * 根据商品IDs获取星范IDs
     */
    List<Integer> findMallInvalidIdsByProductIds(@Param("invalidIds") List<Integer> invalidIds);
    /**
     * 获取所有失效供应商数量
     */
    Integer findSupplierInvalidCount();
    /**
     * 获取失效供应商IDs
     */
    List<Integer> findSupplierInvalidIds();
    /**
     * 获取所有失效项目仪器数量
     */
    Integer findEquipmentInvalidCount();
    /**
     * 获取失效项目仪器IDs
     */
    List<Integer> findEquipmentInvalidIds();
    /**
     * 获取所有失效文章数量
     */
    Integer findArticleInvalidCount();
    /**
     * 获取失效文章IDs
     */
    List<Integer> findArticleInvalidIds();
    /**
     * 获取数据库商品
     * @param identity  用户身份
     * @param keyword   关键词
     * @param shopId    供应商id
     * @param bigTypeId 一级分类id
     * @param smallTypeId 二级分类id
     * @param tinyTypeId 三级分类id
     * @param classifyId 运营分类id
     * @param sortField 排序类型
     * @param sortType  排序顺序
     * @return list
     */
    List<ProductListVo> queryProduct(@Param("identity") Integer identity,
                                     @Param("keyword") String keyword,
                                     @Param("shopId") Integer shopId,
                                     @Param("bigTypeId") Integer bigTypeId,
                                     @Param("smallTypeId") Integer smallTypeId,
                                     @Param("tinyTypeId") Integer tinyTypeId,
                                     @Param("classifyId") Integer classifyId,
                                     @Param("sortField") String sortField,
                                     @Param("sortType") Integer sortType);
    /**
     * 获取数据库供应商
     * @param keyword   关键词
     * @return list
     */
    List<ShopListVo> querySupplier(@Param("keyword") String keyword);
    /**
     * 获取数据库项目仪器
     * @param keyword   关键词
     * @return list
     */
    List<EquipmentListVo> queryEquipment(@Param("keyword") String keyword);
    /**
     * 获取数据库文章
     * @param keyword   关键词
     * @return list
     */
    List<ArticleListVo> queryArticle(@Param("keyword") String keyword, @Param("articleId") Integer articleId, @Param("typeId") Integer typeId, @Param("labelText") String labelText);

}
