package com.caimei365.commodity.mapper;

import com.caimei365.commodity.model.po.ProductImagePo;
import com.caimei365.commodity.model.po.ProductPo;
import com.caimei365.commodity.model.po.ProductSecondPo;
import com.caimei365.commodity.model.vo.AddressVo;
import com.caimei365.commodity.model.vo.BrandVo;
import com.caimei365.commodity.model.vo.SecondDetailVo;
import com.caimei365.commodity.model.vo.SecondListVo;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/4/14
 */
@Mapper
public interface SecondHandMapper {
    /**
     * 二手商品列表
     *
     * @param userIdentity   用户身份
     * @param secondHandType 二手商品分类，1二手仪器，2临期产品，3其他
     * @param instrumentType 二手仪器分类的类型，1轻光电、2重光电、3耗材配件
     * @param name           二手商品名称搜索关键词
     */
    List<SecondListVo> getSeconHandList(@Param("userIdentity") Integer userIdentity, @Param("secondHandType") Integer secondHandType, @Param("instrumentType") Integer instrumentType, @Param("name") String name);

    /**
     * 获取二手商品详情
     *
     * @param productId 商品Id
     */
    SecondDetailVo getSecondHandDetail(Integer productId);

    /**
     * 获取二手商品图片
     *
     * @param productId 商品Id
     */
    List<String> getImageByProductId(Integer productId);

    /**
     * 保存商品二手附加详细信息
     *
     * @param secondPo ProductSecondPo
     */
    void saveSencondHandProduct(ProductSecondPo secondPo);

    /**
     * 二手商品通过地址ID获取详细省市区
     */
    AddressVo getAddressInfo(Integer townId);

    /**
     * 保存商品图片信息
     */
    void insertProductImage(ProductImagePo imagePo);

    /**
     * 保存商品表
     */
    void insertProduct(ProductPo product);

    /**
     * 二手下单页面商品
     *
     * @param searchKeyword  搜索关键词
     * @param secondHandType 二手商品分类，1二手仪器，2临期产品，3其他
     * @param instrumentType 二手仪器分类的类型，1轻光电、2重光电、3耗材配件
     */
    List<SecondListVo> getOrderPageSecondList(String searchKeyword, Integer secondHandType, Integer instrumentType);

    /**
     * 获取对应分类的最新10条有效数据
     *
     * @param secondHandType 二手商品分类，1二手仪器，2临期产品，3其他
     */
    List<SecondListVo> getSecondListByLimit(Integer secondHandType);

    /**
     * 商品品牌列表
     */
    List<BrandVo> getBrandList();
}
