package com.caimei365.commodity.model.dto;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/4/20
 */
@ApiModel("商品发布")
@Data
public class ProductDto implements Serializable {
    private static final long serialVersionUID = 1L;
    /**
     * 供应商id
     */
    @ApiModelProperty("供应商id")
    private Integer shopId;
    /**
     * 商品id
     */
    @ApiModelProperty("商品id")
    private Integer productId;
    /**
     * 名称
     */
    @ApiModelProperty("商品名称")
    private String name;
    /**
     * 内部商品名称
     */
    @ApiModelProperty("内部商品名称")
    private String aliasName;
    /**
     * 商品属性：1产品，2仪器
     */
    @ApiModelProperty("商品属性：1产品，2仪器")
    private Integer commodityType;
    /**
     * 一级分类id
     */
    @ApiModelProperty("一级分类id")
    private Integer bigTypeId;
    /**
     * 二级分类id
     */
    @ApiModelProperty("二级分类id")
    private Integer smallTypeId;
    /**
     * 三级分类Id
     */
    @ApiModelProperty("三级分类id")
    private Integer tinyTypeId;
    /**
     * 品牌Id
     */
    @ApiModelProperty("品牌id")
    private Integer brandId;
    /**
     * 商品类型：0其它类型(默认)，1妆字号，2械字号
     */
    @ApiModelProperty("商品类型：0其它，1妆字号，2械字号")
    private Integer productType;
    /**
     * 商品标签用英文逗号隔开，中文逗号或其它一律不作切割
     */
    @ApiModelProperty("商品标签，逗号隔开")
    private String tags;
    /**
     * 包装规格
     */
    @ApiModelProperty("包装规格")
    private String unit;
    /**
     * 机构价格
     */
    @ApiModelProperty("机构价格")
    private Double price;
    /**
     * 市场价
     */
    @ApiModelProperty("市场价")
    private Double normalPrice;
    /**
     * 是否含税：0不含税，1含税，2未知
     */
    @ApiModelProperty("是否含税：0不含税，1含税，2未知")
    private Integer includedTax;
    /**
     * 最小购买量
     */
    @ApiModelProperty("最小购买量")
    private Integer minBuyNumber;
    /**
     * 库存
     */
    @ApiModelProperty("库存")
    private Integer stock;
    /**
     * 品牌名称
     */
    @ApiModelProperty("品牌名称")
    private String brandName;
    /**
     * 商品货号
     */
    @ApiModelProperty("商品货号")
    private String productCode;
    /**
     * 械字号类型   (基于械字号基础),1：一类，2：二类，3：三类
     */
    @ApiModelProperty("械字号类型")
    private Integer machineType;
    /**
     * 搜索关键词,4个用英文逗号区分,不存在的直接逗号隔空(顺序参考:品牌,学名,市场称呼,大类别,小类别)
     */
    @ApiModelProperty("搜索关键词")
    private String searchKey;
    /**
     * 购买数量: 1逐步增长,2以起订量增长(起订量的倍数增长)
     */
    @ApiModelProperty("购买数量")
    private Integer step;
    /**
     * 械字号资质证书图  (基于械字号基础)
     */
    @ApiModelProperty("械字号资质证书图")
    private String qualificationImg;
    /**
     * 成本价
     */
    @ApiModelProperty("成本价")
    private Double costPrice;
    /**
     * 发票类型(基于是否含税基础)   1增值税票，2普通票, 3不能开票
     */
    @ApiModelProperty("发票类型")
    private Integer invoiceType;
    /**
     * 开票税点(基于不含税基础) :增值税默认13%，普通票6%取值范围[0-100]
     */
    @ApiModelProperty("开票税点")
    private Double taxPoint;
    /**
     * 销售区域：1全部区域， 0指定区域
     */
    @ApiModelProperty("销售区域：1全部区域， 0指定区域")
    private String allAreaFlag;
    /**
     * 指定的销售区域
     */
    @ApiModelProperty("指定的销售区域")
    private String provinceIds;
    /**
     * 商品详情Id
     */
    @ApiModelProperty("商品详情Id")
    private Integer productDetailInfoId;
    /**
     * 商品详情信息
     */
    @ApiModelProperty("商品详情信息")
    private String detailInfo;
    /**
     * 服务详情
     */
    @ApiModelProperty("服务详情")
    private String serviceInfo;
    /**
     * 订购方案
     */
    @ApiModelProperty("订购方案")
    private String orderInfo;
    /**
     * 相关参数与商品图片Json
     */
    @ApiModelProperty("相关参数与商品图片Json")
    private String params;
    /**
     * 仪器培训方式：1线上培训，2线下培训
     */
    @ApiModelProperty("仪器培训方式：1线上培训，2线下培训")
    private Integer trainingMethod;
    /**
     * 售价是否包含：1售价未包含，2售价已包含
     */
    @ApiModelProperty("售价是否包含：1售价未包含，2售价已包含")
    private Integer trainingType;
    /**
     * 培训费用(售价未包含)
     */
    @ApiModelProperty("培训费用(售价未包含)")
    private BigDecimal trainingFee;

}
