package com.caimei365.commodity.model.vo;

import com.caimei365.commodity.model.po.ProductDetailInfoPo;
import com.caimei365.commodity.model.po.ProductImagePo;
import com.caimei365.commodity.model.po.ProductParameterPo;
import io.swagger.annotations.ApiModel;
import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.List;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/4/22
 */
@ApiModel("商品详情")
@Data
public class ProductDetailVo implements Serializable {
    private static final long serialVersionUID = 1L;

    /**
     * 用户收藏标记（1收藏，0未收藏）
     */
    private Integer userLike;
    /**
     * 商品productID
     */
    private Integer productId;
    /**
     * 所属供应商Id
     */
    private Integer shopId;
    /**
     * 商品名称
     */
    private String name;
    /**
     * 内部商品名称
     */
    private String aliasName;
    /**
     * 搜索关键词,4个用英文逗号区分,不存在的直接逗号隔空(顺序参考:品牌,学名,市场称呼,大类别,小类别)
     */
    private String searchKey;
    /**
     * 商品属性：1产品，2仪器
     */
    private Integer commodityType;
    /**
     * 一级分类id
     */
    private Integer bigTypeId;
    /**
     * 二级分类id
     */
    private Integer smallTypeId;
    /**
     * 三级分类Id
     */
    private Integer tinyTypeId;
    /**
     * 主图
     */
    private String mainImage;
    /**
     * 品牌Id
     */
    private Integer brandId;
    /**
     * 商品类型：0其它类型(默认)，1妆字号，2械字号
     */
    private Integer productType;
    /**
     * 商品标签用英文逗号隔开，中文逗号或其它一律不作切割
     */
    private String tags;
    /**
     * 商品货号
     */
    private String productCode;
    /**
     * 包装规格
     */
    private String unit;
    /**
     * 市场价
     */
    private Double normalPrice;
    /**
     * 商品价格
     */
    private Double price;
    /**
     * 价格可见度：0公开价格 1不公开价格 2仅对会员机构公开 price1TextFlag
     */
    private Integer priceFlag;
    /**
     * 启用阶梯价格标识 0否 1是
     */
    private Integer ladderPriceFlag;
    /**
     * 阶梯价格列表
     */
    private List<LadderPriceVo> ladderPriceList;
    /**
     * 成本价
     */
    private Double costPrice;
    /**
     * 商品可见度：（3:所有人可见，2:普通机构可见，1:会员机构可见）
     */
    private Integer visibility;
    /**
     * 商品状态， 0逻辑删除 1待审核 2已上架 3已下架 8审核未通过 9已隐身 10已冻结
     */
    private Integer validFlag;
    /**
     * 是否使用活动角标：1是，空或0不是[与actType搭配使用,仅用于标识非真正活动]
     */
    private Integer actFlag;
    /**
     * 是否含税   0不含税，1含税，2未知
     */
    private Integer includedTax;
    /**
     * 供应商税率:增值专用发票默认13%，增值税普通发票6%取值范围[0-100]
     */
    private Double supplierTaxPoint;
    /**
     * 最小购买量
     */
    private Integer minBuyNumber;
    /**
     * 服务起订量
     */
    private Integer serviceNumber;
    /**
     * 库存
     */
    private Integer stock;
    /**
     * 商品的类别：1正常商品(默认)，2二手商品
     */
    private Integer productCategory;
    /**
     * 添加时间
     */
    private String addTime;
    /**
     * 更新时间
     */
    private String updateTime;
    /**
     * 是否有sku：1有， 0没有
     */
    private Integer hasSkuFlag;
    /**
     * 销量
     */
    private Integer sellNumber;
    /**
     * 排序值
     */
    private Integer sortIndex;
    /**
     * 供应商主推商品标志 0否 1是
     */
    private Integer featuredFlag;
    /**
     * 成本价选中标志：1固定成本 2比例成
     */
    private Integer costCheckFlag;
    /**
     * 相关推荐类型 0自动选择; 1手动推荐
     */
    private Integer recommendType;
    /**
     * 标签数组
     */
    private String[] tagsList;
    /**
     * 品牌名称
     */
    private String brandName;
    /**
     * 一级分类名称
     */
    private String bigTypeName;
    /**
     * 二级分类名称
     */
    private String smallTypeName;
    /**
     * 三级分类名称
     */
    private String tinyTypeName;
    /**
     * 所在分类名称
     */
    private String typeName;
    /**
     * 商品详情
     */
    private ProductDetailInfoPo productDetail;
    /**
     * 商品图片
     */
    private List<ProductImagePo> imageList;
    /**
     * 相关参数
     */
    private List<ProductParameterPo> parametersList;
    /**
     * 械字号类型   (基于械字号基础),1：一类，2：二类，3：三类
     */
    private String machineType;

    /**
     * 购买数量: 1逐步增长,2以起订量增长(起订量的倍数增长)
     */
    private Integer step;
    /**
     * 械字号资质证书图  (基于械字号基础)
     */
    private String qualificationImg;

    /**
     * 发票类型(基于是否含税基础)   1增值税票，2普通票, 3不能开票
     */
    private String invoiceType;
    /**
     * 开票税点(基于不含税基础) :增值税默认13%，普通票6%取值范围[0-100]
     */
    private Double taxPoint;
    /**
     * 销售区域：1全部区域， 0指定区域
     */
    private String allAreaFlag;
    /**
     * 指定的销售区域
     */
    private String provinceIds;
    /**
     * 商品详情信息
     */
    private String detailInfo;
    /**
     * 服务详情
     */
    private String serviceInfo;
    /**
     * 订购方案
     */
    private String orderInfo;
    /**
     * 计算后价格等级
     */
    private Integer priceGrade;
    /**
     * 供应商信息
     */
    private ShopVo shop;
    /**
     * 商品是否处于活动状态 1是 0否
     */
    private Integer actStatus;
    /**
     * 划线价格
     */
    private Double originalPrice;
    /**
     * 促销活动
     */
    private PromotionsVo promotions;
    /**
     * 用户身份: 2-会员机构, 4-普通机构
     */
    private Integer userIdentity;
    /**
     * 最大购买量
     */
    private Integer maxBuyNumber;
    /**
     * 是否复购 0否 1是
     */
    private Integer repurchaseFlag;
    /**
     * 仪器培训方式：1线上培训，2线下培训
     */
    private Integer trainingMethod;
    /**
     * 售价是否包含：1售价未包含，2售价已包含
     */
    private Integer trainingType;
    /**
     * 培训费用(售价未包含)
     */
    private BigDecimal trainingFee;
    /**
     * 商品pc端活动类型，0无活动，1云上美博会
     */
    private Integer pcActType;
    /**
     * 商品小程序端活动类型，0无活动，1云上美博会
     */
    private Integer appletsActType;
    /**
     * 商品资料id
     */
    private Integer archiveId;
}
