package com.caimei365.commodity.service;

import com.caimei365.commodity.model.ResponseJson;
import com.caimei365.commodity.model.po.ProductParameterPo;
import com.caimei365.commodity.model.search.ProductListVo;
import com.caimei365.commodity.model.vo.*;

import java.util.List;
import java.util.Map;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/4/12
 */
public interface PageService {
    /**
     * 获取分类列表
     *
     * @param typeSort 分类类型：1产品，2仪器，0全部
     * @param source   请求来源：www,crm
     */
    ResponseJson<List<BigTypeVo>> getClassify(Integer typeSort, String source);

    /**
     * 产品/仪器页面数据
     *
     * @param pageId 页面信息id
     * @param userId 用户id
     * @param source 来源：1网站，2小程序
     */
    ResponseJson<Map<String, Object>> getClassifyData(Integer pageId, Integer userId, Integer source);

    /**
     * 首页楼层数据
     *
     * @param userId 用户id
     * @param source 来源：1网站，2小程序
     */
    ResponseJson<Map<String, Object>> getHomeData(Integer userId, Integer source);

    /**
     * 首页基础数据（小程序）
     *
     * @param source 来源 : 1 网站 ; 2 小程序
     */
    ResponseJson<Map<String, Object>> getHomeInit(Integer source);

    /**
     * 活动专题楼层数据（美博会）
     *
     * @param pageId 页面id
     * @param userId 用户id
     * @param source 来源 : 1 网站 ; 2 小程序
     */
    ResponseJson<Map<String, Object>> getPageData(Integer pageId, Integer userId, Integer source);

    /**
     * 楼层详情
     *
     * @param floorId 楼层id
     * @param userId  用户id
     * @param source  来源 : 1 网站 ; 2 小程序
     */
    ResponseJson<Map<String, Object>> getPageFloorData(Integer floorId, Integer userId, Integer source);

    /**
     * 分页详情楼层详情
     *
     * @param centreId 分页详情楼层id
     * @param userId   用户id
     * @param source   来源 : 1 网站 ; 2 小程序
     */
    ResponseJson<Map<String, Object>> getPageCentreData(Integer centreId, Integer userId, Integer source);

    /**
     * 商品详情页
     *
     * @param productId 商品Id
     * @param userId    用户Id
     */
    ResponseJson<ProductDetailVo> getProductDetails(Integer productId, Integer userId);

    /**
     * 再次购买商品列表
     *
     * @param userId 用户Id
     */
    ResponseJson<PaginationVo<ProductItemVo>> getBuyAgainProducts(Integer userId, int pageNum, int pageSize);

    /**
     * 项目仪器详情页
     *
     * @param equipmentId 项目仪器Id
     */
    ResponseJson<EquipmentVo> getEquipmentDetails(Integer equipmentId);

    /**
     * 商品详情页-图片
     *
     * @param productId 商品Id
     */
    ResponseJson<List<String>> getProductDetailImages(Integer productId);

    /**
     * 商品详情页-相关参数
     *
     * @param productId 商品Id
     */
    ResponseJson<List<ProductParameterPo>> getProductParameters(Integer productId);

    /**
     * 商品详情页-相关推荐
     *
     * @param productId     商品Id
     * @param recommendType 相关推荐类型: 0自动选择, 1手动推荐
     * @param userId        用户Id
     */
    ResponseJson<List<ProductListVo>> getProductDetailRecommends(Integer productId, Integer recommendType, Integer userId);

    /**
     * 商品维修（链接分享数据）
     *
     * @param code 维修code
     */
    ResponseJson<ProductRepairVo> getProductRepair(String code);

    /**
     * 优惠券标识是否显示
     *
     * @param userId    机构用户id
     * @param productId 商品id
     * @param source    来源 : 1 网站 ; 2 小程序
     * @return
     */
    Boolean setCouponsLogo(Integer userId, Integer productId, Integer source);

    /**
     * 商品资料列表
     * @param keyword       搜索关键词
     * @param productType   商品属性：1产品，2仪器
     * @param pageNum       页码
     * @param pageSize      每页数量
     * @return
     */
    ResponseJson<PaginationVo<ArchiveVo>> getProductArchive(String keyword, Integer productType, Integer pageNum, Integer pageSize);

    /**
     * 商品资料详情
     * @param archiveId     商品资料id
     * @param userId        用户id
     * @return
     */
    ResponseJson<ArchiveDetailVo> getArchiveDetail(Integer archiveId, Integer userId);
}
