package com.caimei365.commodity.service;

import com.caimei365.commodity.model.ResponseJson;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/4/7
 */
public interface SearchProductService {
    /**
     * 根据关键词搜索商品
     *
     * @param keyword   搜索关键字
     * @param identity: 0个人，1协销，2会员机构，3供应商，4普通机构
     * @param pageNum   页码
     * @param pageSize  每页数量
     * @param sortField 排序字段
     * @param sortType  升降序0/1
     * @return JsonStr(list)
     */
    ResponseJson<String> queryProductByKeyword(String keyword, Integer identity, int pageNum, int pageSize, String sortField, Integer sortType);

    /**
     * 根据分类Id搜索商品
     *
     * @param id     bigTypeID/smallTypeID/tinyTypeID
     * @param idType id类型：1一级分类，2二级分类，3三级分类
     * @param identity: 0个人，1协销，2会员机构，3供应商，4普通机构
     * @param pageNum   页码
     * @param pageSize  每页数量
     * @param sortField 排序字段
     * @param sortType  升降序0/1
     * @return JsonStr(list)
     */
    ResponseJson<String> queryProductByType(Integer id, Integer idType, Integer identity, int pageNum, int pageSize, String sortField, Integer sortType);

    /**
     * 根据小程序运营分类Id搜索商品
     *
     * @param id        运营级分类Id
     * @param identity  用户身份 1:协销， 2:会员机构
     * @param pageNum   页码
     * @param pageSize  每页数量
     * @param sortField 排序字段
     * @param sortType  升降序0/1
     * @return JsonStr(list)
     */
    ResponseJson<String> queryProductByClassify(Integer id, Integer identity, int pageNum, int pageSize, String sortField, Integer sortType);

    /**
     * 根据供应商Id搜索商品（商铺内搜索）
     *
     * @param id       供应商Id
     * @param keyword  搜索关键字
     * @param identity  用户身份 1:协销， 2:会员机构
     * @param pageNum   页码
     * @param pageSize  每页数量
     * @param sortField 排序字段
     * @param sortType  升降序0/1
     * @return JsonStr(list)
     */
    ResponseJson<String> querySupplierProduct(Integer id, String keyword, Integer identity, int pageNum, int pageSize, String sortField, Integer sortType);
}
