package com.caimei365.commodity.service;


import com.caimei365.commodity.model.ResponseJson;

import java.util.Map;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/4/6
 */
public interface SearchQueryService {
    /**
     * 获取阿里云索引Id
     *
     * @param docType 文档类型
     * @param docId   文档ID
     * @return int
     */
    Integer getIdByDocId(String docType, Integer docId);
    /**
     * 根据文档类型获取阿里云索引Id集合
     * @param docType 文档类型
     * @return map
     */
    Map<Integer, Integer> getMainIdsByDocType(String docType, int pageNum, int pageSize);
    /**
     * 根据文档类型获取数量
     *
     * @param docType 文档类型
     * @return int
     */
    Integer getRecordByDocType(String docType);

    /**
     * 根据文档类型获取数量(去重用)
     *
     * @param docType 文档类型
     * @param docId   文档ID
     * @return int
     */
    Integer getCountByDocId(String docType, Integer docId);

    /**
     * 根据关键词搜索供应商
     *
     * @param keyword  搜索关键字
     * @param identity  用户身份 1:协销， 2:会员机构
     * @param pageNum   页码
     * @param pageSize  每页数量
     * @return JsonStr(list)
     */
    ResponseJson<String> querySupplierByKeyword(String keyword, Integer identity, int pageNum, int pageSize);

    /**
     * 根据关键词搜索项目仪器
     *
     * @param keyword  搜索关键字
     * @param pageNum   页码
     * @param pageSize  每页数量
     * @return JsonStr(list)
     */
    ResponseJson<String> queryEquipmentByKeyword(String keyword, int pageNum, int pageSize);

    /**
     * 根据关键词搜索文章
     *
     * @param keyword  搜索关键字
     * @param pageNum   页码
     * @param pageSize  每页数量
     * @return JsonStr(list)
     */
    ResponseJson<String> queryArticleByKeyword(String keyword, int pageNum, int pageSize);

    /**
     * 根据文章ID搜索文章
     *
     * @param id 文章id
     * @return JsonStr(list)
     */
    ResponseJson<String> queryArticleByArticleId(Integer id);

    /**
     * 根据分类搜索文章
     *
     * @param id 分类id
     * @param pageNum   页码
     * @param pageSize  每页数量
     * @return JsonStr(list)
     */
    ResponseJson<String> queryArticleByType(Integer id, int pageNum, int pageSize);

    /**
     * 根据标签搜索文章
     *
     * @param id 标签id
     * @param pageNum   页码
     * @param pageSize  每页数量
     * @return JsonStr(list)
     */
    ResponseJson<String> queryArticleByLabel(Integer id, int pageNum, int pageSize);
}
