package com.caimei365.commodity.service;

import com.caimei365.commodity.model.ResponseJson;
import com.caimei365.commodity.model.dto.SecondDto;
import com.caimei365.commodity.model.vo.BrandVo;
import com.caimei365.commodity.model.vo.PaginationVo;
import com.caimei365.commodity.model.vo.SecondDetailVo;
import com.caimei365.commodity.model.vo.SecondListVo;
import org.springframework.http.HttpHeaders;

import java.util.List;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/4/14
 */
public interface SecondHandService {
    /**
     * 二手商品列表
     *
     * @param userId         机构用户id
     * @param secondHandType 二手商品分类，1二手仪器，2临期产品，3其他
     * @param instrumentType 二手仪器分类的类型，1轻光电、2重光电、3耗材配件
     * @param name           二手商品名称搜索关键词
     * @param pageNum        页码
     * @param pageSize       每页数量
     * @return List<SecondHandVo>
     */
    ResponseJson<PaginationVo<SecondListVo>> getSecondHandList(Integer userId, Integer secondHandType, Integer instrumentType, String name, int pageNum, int pageSize);

    /**
     * 获取二手商品详情
     *
     * @param userId    机构用户id
     * @param productId 商品表的商品Id
     * @return SecondDetailVo
     */
    ResponseJson<SecondDetailVo> getSecondHandDetail(Integer userId, Integer productId);

    /**
     * 发布二手商品
     *
     * @param secondDto 对象内容描述{
     *                  "secondHandType" : 二手商品分类，1二手仪器，2临期产品，3其他
     *                  ,"instrumentType" : 二手仪器分类的类型，1轻光电、2重光电、3耗材配件(仅适用于二手仪器分类多个用英文逗号分分隔)
     *                  ,"brandId" : 品牌Id
     *                  ,"name" : 商品名称
     *                  ,"fixedYears" : 出厂日期格式：2020年6月
     *                  ,"maturityYears" : 产品到期日格式：2020年6月（仅适用于临期产品）
     *                  ,"companyName" : 公司名称
     *                  ,"price" : 交易价格
     *                  ,"detailTalkFlag" : 是否启用详聊，1不开启，2开启(开启详聊不展示交易价)
     *                  ,"normalPrice" : 市场价
     *                  ,"originalPrice" : 采购价/原价(该二手原始购买价格）
     *                  ,"stock" : 数量（等同库存）
     *                  ,"productQuality" : 商品成色
     *                  ,"contactName" : 联系人名字
     *                  ,"contactMobile" : 联系方式
     *                  ,"secondProductType" : 设备类型：1医美、2非医美
     *                  ,"townId" : 县区ID
     *                  ,"address" : 详细地址
     *                  ,"image" : 图片信息
     *                  ,"productDetails" : 商品详细信息
     *                  ,"source" : 信息来源 1网站  2CRM  3后台
     *                  }
     * @param headers   HttpHeaders
     */
    ResponseJson releaseSecondHand(SecondDto secondDto, HttpHeaders headers);

    /**
     * 二手下单页面商品
     *
     * @param searchKeyword  搜索关键词
     * @param secondHandType 二手商品分类，1二手仪器，2临期产品，3其他
     * @param instrumentType 二手仪器分类的类型，1轻光电、2重光电、3耗材配件
     */
    ResponseJson<PaginationVo<SecondListVo>> getOrderPageSecondList(String searchKeyword, Integer secondHandType, Integer instrumentType, int pageNum, int pageSize);

    /**
     * 商品品牌列表
     */
    ResponseJson<List<BrandVo>> getBrandList();
}
