package com.caimei365.commodity.service.impl;

import com.aliyun.opensearch.sdk.dependencies.com.google.common.collect.Lists;
import com.caimei365.commodity.components.PriceUtilService;
import com.caimei365.commodity.mapper.PriceMapper;
import com.caimei365.commodity.mapper.PromotionsMapper;
import com.caimei365.commodity.model.ResponseJson;
import com.caimei365.commodity.model.vo.LadderPriceVo;
import com.caimei365.commodity.model.vo.PriceVo;
import com.caimei365.commodity.model.vo.TaxVo;
import com.caimei365.commodity.service.PageService;
import com.caimei365.commodity.service.PriceService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import javax.annotation.Resource;
import java.util.List;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/4/9
 */
@Slf4j
@Service
public class PriceServiceImpl implements PriceService {
    @Resource
    private PriceMapper priceMapper;
    @Resource
    private PromotionsMapper promotionsMapper;
    @Resource
    private PriceUtilService priceUtilService;
    @Resource
    private PageService pageService;

    /**
     * 获取商品详情价格
     *
     * @param userId    用户Id
     * @param productId 商品Id
     * @return PriceVo
     */
    @Override
    public ResponseJson<PriceVo> getDetailPrice(Integer userId, Integer productId) {
        // 数据库获取基本价格信息
        PriceVo price = priceMapper.getDetailPrice(productId);
        // 根据用户id设置详细价格
        priceUtilService.setPriceByUserId(price, userId);
        log.info(">>>读取商品价格，商品ID:" + productId + ",用户ID:" + userId);
        return ResponseJson.success(price);
    }

    /**
     * 获取商品列表价格
     *
     * @param userId     用户Id
     * @param productIds 商品Id
     * @return List<PriceVo>
     */
    @Override
    public ResponseJson<List<PriceVo>> getListPrice(Integer userId, String productIds, Integer source) {
        List<Integer> productIdList = Lists.newArrayList();
        if (productIds.contains(",")) {
            String[] productArr = productIds.split(",");
            for (String id : productArr) {
                productIdList.add(Integer.parseInt(id));
            }
        } else {
            productIdList.add(Integer.parseInt(productIds));
        }
        if (productIdList.size() == 0 || null == userId) {
            return ResponseJson.error("商品Id参数错误", null);
        }
        // 数据库获取基本价格信息
        List<PriceVo> priceList = priceMapper.getListPriceByProductIds(productIdList);
        for (PriceVo price : priceList) {
            // 根据用户id设置详细价格
            priceUtilService.setPriceByUserId(price, userId);
            Boolean couponsLogo = pageService.setCouponsLogo(userId, price.getProductId(), source);
            price.setCouponsLogo(couponsLogo);
        }
        log.info(">>>读取商品列表价格，商品IDs:" + productIds + ",用户ID:" + userId);
        return ResponseJson.success(priceList);
    }

    /**
     * 获取阶梯价格
     *
     * @param productId 商品Id
     * @return LadderPriceVo
     */
    @Override
    public ResponseJson<List<LadderPriceVo>> getLadderPrice(Integer productId) {
        List<LadderPriceVo> ladderPrices = priceMapper.getLadderPricesByProductId(productId);
        TaxVo tax = priceMapper.getTaxByProductId(productId);
        if (!CollectionUtils.isEmpty(ladderPrices)) {
            priceUtilService.setLadderPriceList(ladderPrices, tax);
        }
        return ResponseJson.success(ladderPrices);
    }
}
