package com.caimei365.commodity.utils;

import com.aliyun.opensearch.sdk.dependencies.org.json.JSONArray;
import com.aliyun.opensearch.sdk.dependencies.org.json.JSONObject;
import com.caimei365.commodity.model.search.ArticleListVo;
import com.caimei365.commodity.model.search.EquipmentListVo;
import com.caimei365.commodity.model.search.ProductListVo;
import com.caimei365.commodity.model.search.ShopListVo;

import java.util.ArrayList;
import java.util.List;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/4/7
 */
public class Json2PojoUtil {
    /**
     * 阿里云查询出json转换成商品pojo
     * @param jsonArray json
     * @return ProductListVo
     */
    public static List<ProductListVo> toProductList(JSONArray jsonArray) {
        List<ProductListVo> productList = new ArrayList<>();
        for (int i=0; i<jsonArray.length(); i++) {
            JSONObject json = jsonArray.getJSONObject(i);
            ProductListVo product = new ProductListVo();
            /* 主键Id */
            product.setMainId(json.getInt("id"));
            /* 商品Id */
            product.setProductId(json.getInt("p_id"));
            /* 名称name */
            product.setName(json.getString("p_name"));
            /* 搜索关键词searchKey */
            product.setKeyword(json.getString("p_keyword"));
            /* 主图mainImage */
            product.setImage(json.getString("p_image"));
            /* 是否公开机构价 0公开价格 1不公开价格 */
            product.setPriceFlag(json.getInt("p_price_flag"));
            /* 计算后价格等级 */
            product.setPriceGrade(json.getInt("p_price_grade"));
            /* 商品货号 */
            product.setCode(json.getString("p_code"));
            /* 包装规格 */
            product.setUnit(json.getString("p_unit"));
            /* 品牌 */
            product.setBrandName(json.getString("p_brand_name"));
            /* 所属供应商Id，关联供应商表 */
            product.setShopId(json.getInt("p_supplier_id"));
            /* 美博会商品活动状态 */
            product.setBeautyActFlag(json.getInt("p_act_flag"));

            productList.add(product);
        }
        return productList;
    }

    /**
     * 阿里云查询出json转换成供应商pojo
     * @param jsonArray json
     * @return ShopListVo
     */
    public static List<ShopListVo> toShopList(JSONArray jsonArray) {
        List<ShopListVo> shopList = new ArrayList<>();
        for (int i=0; i<jsonArray.length(); i++) {
            ShopListVo shop = new ShopListVo();
            JSONObject json = jsonArray.getJSONObject(i);
            /* 主键Id */
            shop.setMainId(json.getInt("id"));
            /* 供应商Id */
            shop.setShopId(json.getInt("s_id"));
            /* 供应商名称name */
            shop.setName(json.getString("s_name"));
            /* 供应商logo */
            shop.setLogo(json.getString("s_logo"));
            /* 供应商牌照 */
            shop.setLicense(json.getString("s_license"));
            /* 经营品项 */
            shop.setBusiness(json.getString("s_business"));
            /* 所在省市地址 */
            shop.setAddress(json.getString("s_address"));
            /* 供应商下商品 */
            JSONArray productArr = json.getJSONArray("products");
            List<ProductListVo> productList = toProductList(productArr);
            shop.setProducts(productList);

            shopList.add(shop);
        }
        return shopList;

    }

    /**
     * 阿里云查询出json转换项目仪器pojo
     * @param jsonArray json
     * @return ShopListVo
     */
    public static List<EquipmentListVo> toEquipmentList(JSONArray jsonArray) {
        List<EquipmentListVo> equipmentList = new ArrayList<>();
        for (int i=0; i<jsonArray.length(); i++) {
            EquipmentListVo equipment = new EquipmentListVo();
            JSONObject json = jsonArray.getJSONObject(i);
            /* 阿里云索引Id */
            equipment.setMainId(json.getInt("id"));
            /* 网页ID */
            equipment.setId(json.getInt("e_id"));
            /* 网页标题 */
            equipment.setName(json.getString("e_name"));
            /* 主图 */
            equipment.setImage(json.getString("e_image"));

            equipmentList.add(equipment);
        }
        return equipmentList;
    }

    /**
     * 阿里云查询出json转换成文章pojo
     * @param jsonArray json
     * @return ShopListVo
     */
    public static List<ArticleListVo> toArticleList(JSONArray jsonArray) {
        List<ArticleListVo> articleList = new ArrayList<>();
        for (int i=0; i<jsonArray.length(); i++) {
            ArticleListVo article = new ArticleListVo();
            JSONObject json = jsonArray.getJSONObject(i);
            /* 阿里云索引Id */
            article.setMainId(json.getInt("id"));
            /* 文章ID */
            article.setArticleId(json.getInt("a_id"));
            /* 文章标题 */
            article.setTitle(json.getString("a_title"));
            /* 文章主图 */
            article.setImage(json.getString("a_image"));
            /* 文章作者 */
            article.setPublisher(json.getString("a_publisher"));
            /* 发布日期 */
            article.setPublishDate(json.getString("a_publish_date"));
            /* 文章摘要 */
            article.setIntro(json.getString("a_intro"));
            /* 浏览量 */
            article.setPv(json.getInt("a_pv"));
            /* 信息分类Id */
            article.setTypeId(json.getInt("a_type_id"));
            /* 信息分类文本 */
            article.setTypeText(json.getString("a_type_text"));
            /* 标签 id数组 */
            article.setLabelIds(json.getString("a_label_ids"));
            /* 标签 文本数组 */
            article.setLabelText(json.getString("a_label_text"));

            articleList.add(article);
        }
        return articleList;
    }


}
